@@ -331,13 +331,11 @@ class Device():
 
     def getModules(self):
         endpoint = f'network-device/module?deviceId={self.id}'
-        data = restcall('GET', self.dnac, endpoint)
-
-        modules = data['modules']
-        self.modules = modules
+        modules = restcall('GET', self.dnac, endpoint)
 
+        self.modules = modules.get('response')
         switches = []
-        for module in modules:
+        for module in self.modules:
             name = module['name']
             switch = str((re.findall(r'Switch \d', name))).strip("[']")
             switches.append(switch)
