@@ -190,10 +190,6 @@ class Dnac:
         headers = {
             'x-auth-token': self.authToken
         }
- #       response = requests.request(
- #           "GET", url, headers=headers, data=payload, verify=self.verifySSL, timeout=self.timeout)
- #       data = json.loads(response.text)
-
 
         response = restcall('GET', self, endpoint)
         data = response
@@ -211,7 +207,6 @@ class Dnac:
                                serialNumber + ' not found in pnp.')
 
     def getInventoryDevies(self, **kwargs):
-
         # Setting attributes from kwargs
         if 'sn' in kwargs:
             serialNumber = kwargs['sn']
@@ -258,6 +253,8 @@ class Dnac:
             for device in data:
                 if re.match(rf'{hostname}.*', device['hostname']):
                     return device
+        return None
+
 
     def pullTemplates(self, **kwargs):
         path = ""
